/**
 * Introduction
 *
 * @title ROV - Easy applications from C
 *
 * @copyright Jason Tribbeck / 7th ARM 1994-2001
 *
 * @authors Jason Tribbeck
 *
 * @file font.h
 *
 * @type helper
 *
 * @description
 *
 * The font helper deals with font issues, such as painting, selecting,
 * listing and so forth.
 */

#ifndef __rov_font
#define __rov_font


#ifdef __cplusplus
extern "C"
{
#endif

/**
 * Registers a font.
 * @param font_name the font name.
 * @param xpts the width in points * 16.
 * @param ypts the height in points * 16.
 * @return the font handle (or zero for no font found).
 * @see font_lose()
 * @see font_setfont()
 */
int font_find(char *font_name,
	      int xpts,
	      int ypts);

/**
 * Deregisters a font handle.
 * @param handle the font handle.
 * @see font_find()
 */
void font_lose(int handle);

/**
 * Draw a string on a canvas using a font.
 * @param str the string to print.
 * @param flags the painting flags.
 * @param x the x coordinate.
 * @param y the y coordinate.
 * @note Call font_setfont() to select the font handle prior
 * to painting.
 * @note If flags has FONT_OSCOORDINATES bit set, then the canvas origin is
 * added, making the coordinates canvas coordinates. Otherwise, points are
 * used.
 * @see font_setfont()
 * @see Font paint flags
 */
void font_paint(char *str,
		int flags,
		int x,
		int y);

/**
 * Convert a pair of font coordinates to OS coordinates.
 * @param xf the x font coordinate (points).
 * @param yf the y font coordinate (points).
 * @param xo the pointer to store the x OS coordinate.
 * @param yo the pointer to store the y OS coordinate.
 * @note If either pointer is NULL, then that value is not
 * stored.
 */
void font_converttoos(int xf,
		      int yf,
		      int *xo,
		      int *yo);

/**
 * Convert a pair of OS coordinates to font coordinates.
 * @param xo the x OS coordinate.
 * @param yo the y OS coordinate.
 * @param xf the pointer to store the x font coordinate (points).
 * @param yf the pointer to store the y font coordinate (points).
 * @note If either pointer is NULL, then that value is not
 * stored.
 */
void font_converttopoints(int xo,
			  int yo,
			  int *xf,
			  int *yf);

/**
 * Set a font as the current font to use.
 * @param handle the font handle.
 * @see font_find()
 */
void font_setfont(int handle);

/**
 * Get the current font handle
 * @return the current font handle.
 */
int font_currentfont(void);

/**
 * Sets the font colours.
 * @param handle the handle to use (or 0 for current handle).
 * @param bcol background logical colour.
 * @param fcol foreground logical colour.
 * @param fco foreground colour offset.
 * @note This does not use ColourTrans. If you want to use ColourTrans, use draw_setfontcolour().
 * @see draw.h
 */
void font_setfontcolours(int handle,
			 int bcol,
			 int fcol,
			 int fco);

/**
 * List fonts
 * @param buffer the pointer to the resultant buffer.
 * @param count the current counter (start at 0).
 * @param b_size the size of the buffer.
 * @param font_name the pointer to the font name buffer.
 * @param fn_size the size of the font name buffer.
 * @return the current counter, or -1 if no more, or -2 if an error
 * occurred.
 */
int font_listfonts(char *buffer,
		   int count,
		   int b_size,
		   char *font_name,
		   int fn_size);

/**
 * Gets the width of a character
 * @param handle font handle
 * @param chr the character to get the width of
 * @param flags the flags to use.
 * @return the width (either in points or OS coordinates).
 * @see FONT_OSCOORDINATES
 */
int font_charwidth(int handle,
		   char chr,
		   int flags);

/**
 * Gets the width of the string in the current font.
 * @param str the string.
 * @param max the maximum width (in points).
 * @param strl the string length.
 * @return the length in points.
 * @see font_setfont()
 * @see font_stringcut()
 */
int font_stringwidth(char *str,
		     int max,
		     int strl);

/**
 * Indicate where the string should be cut.
 * @param str the string.
 * @param max the maximum width (in points).
 * @param strl the string length.
 * @return the index of the cut position.
 * @see font_setfont()
 * @see font_stringwidth()
 */
int font_stringcut(char *str,
		   int max,
		   int strl);

/**
 * @section Font paint flags
 */
#define FONT_PLOTRUBOUTBOX (1<<1)
#define FONT_OSCOORDINATES (1<<4)


#ifdef __cplusplus
}
#endif

#endif
